<?php
/*
	Plugin Name: Google Picasa Viewer
	Plugin URI: http://nakunakifi.com
	Description: Add Google Picasa albums to your blog posts, pages and sidebar.
	Author: Ian Kennerley - <a href='http://twitter.com/nakunakifi'>@nakunakifi</a> on twitter
	Version: 1.0
	Author URI: http://nakunakifi.com

	Copyright (c) 2011, nakunakifi.com, Ian Kennerley.
	
	This program is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 2
	of the License, or (at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*/

	// Turn this off on a live site
	error_reporting( E_ALL ); 
	// error_reporting(E_Error);
	// error_reporting(0);
	
	
	// Include the main Google Picasa API
	include 'class-PicasaAPI.php';
	
	
	/*
		Setup custom URL parameters for use 
		when displaying gallery images
	*/
	
	/*-------------------------------------*/
	function add_query_var( $qvars ) {
	
	     $qvars[] = 'album_id';     
	     return $qvars;
	}
	
	// Add a new URL parameter
	add_filter('query_vars', 'add_query_var');

	// Retrieve and display the URL parameter
	function output_album_id() {
	
	     global $wp_query;
	   
/*
		 echo '<pre>';
	     print_r($wp_query->query_vars);
	     echo '</pre>'; 
*/
	
	   
	     if( isset( $wp_query->query_vars['album_id'] )) {
	          return $wp_query->query_vars['album_id'];
	     }
	}
	/*-------------------------------------*/



	/*
		Get Pages into a drop-down list
	*/
	function list_pages() {
	
		$get_page;
		$pages_list = get_pages();
		$get_page = array();
				
		foreach( $pages_list as $apage ) {
		
			$get_page[$apage->ID] = $apage->post_title;	
			error_log( 'Page id ' . $apage->ID );
		}
		
		array_unshift( $get_page, "Select a page:" );
		
		return $get_page;
	}



	define( 'PICASA_PLUGIN_URL', WP_PLUGIN_URL.'/'.str_replace(basename( __FILE__),"",plugin_basename(__FILE__)) );
	
	
	function add_header_code() {
		
		if( function_exists( 'wp_register_script' ) ) {
			
			// http://codex.wordpress.org/Function_Reference/wp_enqueue_script
			wp_register_script( 'nak_google_picasa_albums-fb', PICASA_PLUGIN_URL . 'fancybox/jquery.fancybox-1.3.4.js', array('jquery'),1 );
			wp_register_script( 'nak_google_picasa_albums-js', PICASA_PLUGIN_URL . 'js/base.js', array('jquery'),1 );
		
		
			if( function_exists( 'wp_enqueue_script' ) ) {
				wp_enqueue_script( 'nak_google_picasa_albums-fb' );
				wp_enqueue_script( 'nak_google_picasa_albums-js' );
			}
			
		}


		if( function_exists( 'add_action' )) { add_action( 'wp_head', 'writeCSS' ); }
			
	}	
	
	
	function writeCSS() 
	{
		echo '<link rel="stylesheet" type="text/css" href="'. PICASA_PLUGIN_URL . 'fancybox/jquery.fancybox-1.3.4.css">';
		echo '<link rel="stylesheet" type="text/css" href="'. PICASA_PLUGIN_URL . 'css/style.css">'; 
	}
	

	// Add required css/js to header
	// only if not admin side of things
	if( !is_admin() ) { add_header_code(); }



	/*
		Main Google Picasa Plugin Class
	*/
	class WPPicasa {
		
		// Define some variables
		private $page;
	
		// 
		public function __construct() {
			
			$this->pluginPath = dirname( __FILE__ );
			$this->pluginUrl = WP_PLUGIN_URL . '/' . str_replace( basename( __FILE__ ),"",plugin_basename( __FILE__ ) );
			
			add_shortcode( 'nak_google_picasa_albums', array($this, 'shortcode_albums') );
			add_shortcode( 'nak_google_picasa_album_images', array($this, 'shortcode_album_images') );
						
			// Add shortcode support for widgets
			if ( ! is_admin() ){ add_filter( 'widget_text', 'do_shortcode', 11 ); }
			
			if( isset( $_GET['page'] ) ? $this->page = $_GET['page'] :  $this->page = 1 );
			
		}

	
		/*
			Display Albums when using shortcode
		*/
		public function shortcode_albums( $atts ) {
			
			$options = get_option( 'nak_gp_options' );
			
			// extract the attributes into variables
			extract( shortcode_atts( array(
				'user' 				 => $options['username'],
				'pass' 				 => $options['password'],
				'max_album_results'  => $options['max_album_results'],
				'max_results' 		 => $options['max_results'],
				'album_thumb_size' 	 => $options['album_thumb_size'],
				'album_results_page' => $options['album_results_page'],
			), $atts) );
			
			// Create instance of PicasaAPI class
			$my_picasa = new PicasaAPI( $options['username'], $options['password'] );
			
			// Call user albums
			echo $user_albums = $my_picasa->output_album_display( $max_album_results, $album_thumb_size, strtolower( $options['album_results_page'] ) );
			
		}
	
			
		/*
			Display Album's Images when using shortcode
		*/
		public function shortcode_album_images( $atts ) {
			
			// Get user credentials and prefs from database
			$options = get_option( 'nak_gp_options' );

			// Create instance of GoogleAPI class
			$my_picasa = new PicasaAPI( $options['username'], $options['password'] );
			
			// Get album ID
			if( function_exists( 'output_album_id' ) ){ $album_id = output_album_id(); }
			
			if( ! isset($album_id) ) {
				return false;
				exit;
			}
			
			
			// Extract the attributes into variables
			extract( shortcode_atts( array(
				'user' 				=> $options['username'],
				'pass' 				=> $options['password'],
				'max_results' 		=> $options['max_results'],
				'thumb_size' 		=> $options['thumb_size'],
				'album_thumb_size'	=> $options['album_thumb_size'], 
				'max_results' 		=> $options['max_results'], 
				'max_image_size' 		=> $options['max_image_size'], 
			), $atts ) );
				
				
			echo $my_picasa->output_album_images_display( $album_id, $thumb_size, $max_image_size, $max_results, $this->page );
			
		}
					
	}


	// Add menu for options page
	add_action( 'admin_menu', 'nak_gp_add_page' );
	function nak_gp_add_page() {
		add_options_page( 'Google Picasa Options', 'Google Picasa', 'manage_options', 'nak_gp', 'nak_gp_options_page' );
	}


	// Draw the options page
	function nak_gp_options_page() {
	
		global $get_page;
	
		if ( !current_user_can( 'manage_options') ){ wp_die( __( 'You do not have sufficient permissions to access this page.' ) ); }
		
		?>
			<div id="wrap">
				<?php screen_icon(); ?>
				<h2>Google Picasa Settings Page</h2>
				<form method="post" action="options.php">
					<?php
						if( function_exists('settings_fields') ) {
							settings_fields( 'nak_gp_options' ); // needs to match register_settings()
						}
						
						// 
						if( function_exists( 'do_settings_sections' ) )	{
							do_settings_sections( 'nak_gp' );
						}
						
						// Grab the form
						nak_gp_setting_input();
					?>
		
					<p class="submit">
						<input type="submit" name="submit" class="button-primary" value="<?php _e('Save Changes') ?>" />
					</p>
		
				</form>
			</div>
	<?php
	}



	// Register and define the settings
	add_action( 'admin_init', 'nak_gp_admin_init' );
	function nak_gp_admin_init() {
		register_setting(
			'privacy', 
			'nak_gp_options',
			'nak_gp_validate_options' 
		);
			
		add_settings_field(
			'nak_gp_text_stringcunt',
			'Enter text here',
			'nak_gp_setting_input',
			'privacy',
			'default'
		);	
		
		register_setting( 'nak_gp_options', 'nak_gp_options', 'nak_gp_validate_options' ); // settings_fields
	}


	// Display and fill the form field
	function nak_gp_setting_input() {
	
		global $get_page;
		
		// get option 'text_string' value from the database
		$options = get_option( 'nak_gp_options' );
		
		?>
		
		<table class="form-table">
			<tr valign="top">
				<th scope="row">Username / Email</th>
				<td>
					<input type="text" name="nak_gp_options[username]" value="<?php echo $options['username']; ?>" />
			</tr>
			<tr>
				<th scope="row">Password</th>
				<td>
					<input type="password" name="nak_gp_options[password]" value="<?php echo $options['password']; ?>" />
			</tr>
			
			<tr>
				<th scope="row">Max Album Results per Page</th>
				<td>
					<input type="number" name="nak_gp_options[max_album_results]" value="<?php echo $options['max_album_results']; ?>" />
				</td>
			</tr>
			<tr>
				<th scope="row">Album Thumb Size (px)</th>
				<td>
					<input type="number" name="nak_gp_options[album_thumb_size]" value="<?php echo $options['album_thumb_size']; ?>" />
				</td>
			</tr>
			<tr>
				<th scope="row">Max Image Results per Page</th>
				<td>
					<input type="number" name="nak_gp_options[max_results]" value="<?php echo $options['max_results']; ?>" />
				</td>
			</tr>
			<tr>
				<th scope="row">Thumb Size (px)</th>
				<td>
					<input type="number" name="nak_gp_options[thumb_size]" value="<?php echo $options['thumb_size']; ?>" />
				</td>
			</tr>
			<tr>
				<th scope="row">Max Images Size (px)</th>
				<td>
					<input type="number" name="nak_gp_options[max_image_size]" value="<?php echo $options['max_image_size']; ?>" />
				</td>
			</tr>
			<tr>
				<th>Page to show album results on (Note: this is the page to place the shortcode, nak_google_picasa_album_images)</th>
				<td>
				<select style="width:240px;" name="nak_gp_options[album_results_page]" id="">
				<?php 
					foreach(list_pages() as $val => $page)
					{ 
						?><option value="<?php echo $page; ?>" <?php if ( $options['album_results_page'] == $page) { echo 'selected="selected"'; } ?>><?php echo $page; ?></option>
				<?php } ?>
				</select>
				</td>
			</tr>
		</table>
		
		<?php
	}




// Validate user input
function nak_gp_validate_options( $input ) {

	$errors = array();
	
	$valid['username']        = esc_attr( $input['username'] );
	$valid['password']        = esc_attr( $input['password'] );
	$valid['max_album_results'] = esc_attr( $input['max_album_results'] );
	$valid['album_thumb_size']  = esc_attr( $input['album_thumb_size'] );
	$valid['max_results']      = esc_attr( $input['max_results'] );
	$valid['thumb_size']       = esc_attr( $input['thumb_size'] );
	$valid['max_image_size']    = esc_attr( $input['max_image_size'] );
	
	$valid['album_results_page']    = esc_attr( $input['album_results_page'] );


	// Make sure user name is not empty
	if( $valid['username'] == '' ) {
		$errors['username'] = 'Please enter your Google Picasa username.';		
	}

	if( $valid['password'] == '') {
		$errors['password'] = 'Please enter your Google Picasa password.';		
	}
	
	// Validate numbers
	// Make sure Max Album Results is numeric
	if( !is_numeric( $valid['max_album_results'] ) ) {
		$errors['max_album_results'] = 'Please enter a number for the number of albums to show on a page.';
	}	

	if( !is_numeric( $valid['album_thumb_size'] ) ) {
		$errors['album_thumb_size'] = 'Please enter a number in pixels for the album thumbnail size.';
	}	

	if( !is_numeric( $valid['max_results'] ) ) {
		$errors['max_results'] = 'Please enter a number for the number of results to show on a page.';
	}	

	if( !is_numeric( $valid['thumb_size'] ) ) {
		$errors['thumb_size'] = 'Please enter a number in pixels for the image thumbnail size.';
	}	

	if( !is_numeric($valid['max_image_size'] ) ) {
		$errors['max_image_size'] = 'Please enter a number in pixels for image size in the lightbox (e.g. 600).';
	}	


	// Display all errors together
	if( count( $errors ) > 0 ) {
	
		// Display errors
		foreach( $errors as $err ) {
			$err_msg .= "$err<br><br>"; 
		}

		add_settings_error(
			'nap_gp_text_string',
			'nak_gp_texterror',
			$err_msg,
			'error'
		);
	}

	return $valid;
}


	/*************************************************
	*
	*	Set up 'Widget' to display albums
	*	Drag and drop widget to a widgetized area 
	*	of the theme
	*
	**************************************************/
	
	// use widgets_init action hook to execute custom function and register widget
	add_action("widgets_init", array('Widget_DisplayAlbums', 'register'));

	class Widget_DisplayAlbums extends WP_Widget {

	     function widget( $args ) {  	
	     		
			$wpPicasa 	= new WPPicasa();
			$options 	= get_option( 'nak_gp_options' );
			
			echo $args['before_widget'];
			echo $args['before_title'] . "Google Picasa Albums" . $args['after_title'];
			
			// Create instance of PicasaAPI class
			if( $my_picasa = new PicasaAPI( $options['username'], $options['password'] ) ) {
				
				// Call user albums
				$user_albums = $my_picasa->output_album_display( $options['max_album_results'], $options['album_thumb_size'], strtolower($options['album_results_page'] ) );	
			}
			
			echo $user_albums;
			echo $args['after_widget'];
			
	     }
	
	     function register() {	          
	          
	          $options = array( 'description' => 'MY DESCRIPTION' );
	          $callback = array( 'Widget_DisplayAlbums', 'widget' );
	          
	          wp_register_sidebar_widget(
	          	'nak_gp_viewer',
	          	'Google Picasa Albums',
	          	$callback,
	          	$options
	          );
	     }
	}

	// Instantiate a Class	
	$wpPicasa = new WPPicasa();
?>